@@ -58,7 +58,7 @@ if [ "$1" == 'getWlanInformation' ]; then
 fi 
 
 if [ "$1" == 'readESSIDs' ]; then
-    cat $2/wlanInfo-01.csv | grep -e "$3" | awk -F"," 'BEGIN {OFS = ","}; {print $14}'
+    cat $2/wlanInfo-01.csv | grep -e $3 | awk -F"," 'BEGIN {OFS = ","}; {print $14}'
 fi 
 
 if [ "$1" == 'readESSIDinfo' ]; then 
@@ -74,14 +74,14 @@ fi
 
 if [ "$1" == 'capture' ]; then
     if [ "$5" == 'WPA' ]; then
-       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
+       airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/"$6" wlan0
     else
-       airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
+       airodump-ng --ivs --channel $2 --bssid $3 --write $4/capturedData/$5/"$6" wlan0
     fi   
 fi 
 
 if [ "$1" == 'authenticate' ]; then
-    aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
+    aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4" wlan0
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
