@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '1.12'
-Build = '1'
+Build = '2'
 
 import sys
 import os
@@ -130,6 +130,10 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        
        # print driverStateInjection, interfaceStateMonitor
 
+       ##Clean the interface
+       self.ui.scanList.clear()
+       self.ui.textBrowser.clear()
+       
        ##Check first if the correct drivers are loaded and the interface is in monitor mode
        if driverStateInjection == 'False' or interfaceStateMonitor == 'False':
           message ='ERROR: Cannot scan for available networks.\n\nThe drivers or the interface are not to the correct state.\nPlease configure them from the available menu option.'
@@ -141,9 +145,11 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           showQuickMessage(message) 
           
           os.system('sudo %s/%s getWlanInformation %s %s' % (pathMain, helperScript, pathTemp, duration))
-          message ='Scan for available networks completed!'
+          message ='Scan for available networks completed!\nChoose WEP or WPA..'
           showQuickMessage(message)
 
+       self.ui.textBrowser.append(message)
+
     def displayNetworks(self): #FIXME: read ESSIDs directly and not from the file.
        '''Show available networks in the UI.'''
 
@@ -174,12 +180,12 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        values.sort(key=str.lower)             ##sort them by name.
        # print "ESSIDs sorted:\n", values
 
-       # print "BSSIDs to put in the list:\n", values
+       print "BSSIDs to put in the list:\n", values
        self.ui.scanList.addItems(values)
 
     def displayNetworkInformation(self): #FIXME: read wlan info directly and not from a file.
 
-       global essid, bssid, channel, encryption
+       global essid, bssid, channel, encryption, essid_clean
     
        if self.ui.scanList.currentRow() == -1:
           self.ui.textBrowser.clear()
@@ -187,13 +193,15 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           return
        self.ui.captureButton.setEnabled(True)
        essid = self.ui.scanList.currentItem().text()
-       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s %s' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
+       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s \"%s\"' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
+       
+       print essidInfo
        
        essid = essidInfo[0]
        bssid = essidInfo[1]
        channel = essidInfo[2]
        encryption = essidInfo[3]
-       essid = essid.strip()
+       essid = essid.lstrip(" ").rstrip(" ")
        bssid = bssid.strip()
        channel = channel.strip()
        encryption = encryption.strip()
@@ -203,6 +211,13 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        self.ui.textBrowser.append('MAC: ' + bssid)
        self.ui.textBrowser.append('Ch: ' + channel + ' Security: ' + encryption)
 
+       
+       essid_clean = essid
+       character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<'] 
+       for i in character_list:
+          essid_clean = essid_clean.replace(i,'_')
+       print 'essid (clean): ', essid_clean   
+       
     def executeCapture(self):
        '''Opens an xterm window that captures the packets.'''
    
@@ -236,8 +251,9 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           self.ui.injectionButton.setEnabled(False)
           self.ui.deauthenticateButton.setEnabled(True)
           
-       # print "capture options: ", channel, bssid, pathTemp, encryption, essid
-       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s %s" &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
+       # print "capture options: ", channel, bssid, pathTemp, encryption, essid, essid_clean
+       # os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
+       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid_clean))
       
     def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac; atm ignoring essid and just broadcasting. 
        '''Opens an xterm window that sends deauthentication packets.'''
@@ -248,7 +264,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
     def executeAuthenticate(self):
        '''Opens an xterm window that sends authentication packets.'''
        
-       # print "authenticate options: ", essid, bssid, myMAC
+       # print "authenticate options: ", bssid, myMAC, essid
        os.system('osso-xterm -e "sudo %s/%s authenticate %s %s \"%s\" " &' % (pathMain, helperScript, bssid, myMAC, essid))
 
     def executeInjection(self):
@@ -518,13 +534,19 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        
        global deleteModeOn
        deleteModeOn = 'True'
+
+       self.setWindowTitle('Deletion')
        
        self.ui.decryptButton.setEnabled(False)
        self.ui.decryptButton.setText('Delete')       
        self.ui.selectCommonRadio.setEnabled(False)
+
        self.ui.actionEnableDeleteOptions.setEnabled(False)
        self.ui.actionDisableDeleteOptions.setEnabled(True)
-       self.setWindowTitle('Deletion')
+       
+       ##Hide the dictionary selection buttons 
+       self.ui.dictionaryButton.setHidden(True)
+       self.ui.dictionaryLine.setHidden(True)
        
     def disableDeleteOptions(self):
        '''Disable in the UI the Delete buttons'''
@@ -573,7 +595,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        ##Decrypt files
        if deleteModeOn == 'False':
           if self.ui.selectCommonRadio.isChecked():
-             name = self.capfile.strip().partition('-')
+             name = self.capfile.strip().partition('-') #not ideal since name with "-" will be split earlier
              name = name[0]
              suffix = self.capfile.strip().partition('.')
              suffix = suffix[1]
